The Raspberry Mint extension - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The Raspberry Mint extension

The `raspberry-mint` extension provides Betty’s default theme.

Important

This extension requires Node.js.

Enable this extension in your project’s configuration file as follows:

YAML

    extensions:
      raspberry-mint: {}

JSON

    {
      "extensions": {
        "raspberry-mint": {}
      }
    }

## Configuration

This extension is configurable:

YAML

    extensions:
      raspberry-mint:
        configuration:
          primary_color: '#b3446c'
          secondary_color: '#3eb489'
          tertiary_color: '#ffbd22'
          featured_entities:
            - entity_type: person
              entity: P123
            - entity_type: place
              entity: Amsterdam

JSON

    {
      "extensions": {
        "raspberry-mint": {
          "configuration" : {
            "primary_color": "#b3446c",
            "secondary_color": "#3eb489",
            "tertiary_color": "#ffbd22",
            "featured_entities": [
              {
                "entity_type": "person",
                "entity": "P123"
              },
              {
                "entity_type": "place",
                "entity": "Amsterdam"
              }
            ],
          }
        }
      }
    }

### `primary_color`

optional

The case-insensitive hexadecimal code for the primary color. Defaults to `#b3446c`.

### `secondary_color`

optional

The case-insensitive hexadecimal code for the secondary color. Defaults to `#3eb489`.

### `tertiary_color`

optional

The case-insensitive hexadecimal code for the tertiary color. Defaults to `#ffbd22`.

### `featured_entities`

optional

A list of entities to feature on the front page. Each item has the following configuration:

#### `featured_entities[].entity_type`

required

The entity type ID of the entity (type) to feature, e.g. `person`.

#### `featured_entities[].entity`

required

The entity ID of the entity to feature, e.g. `P123`.

## Templating

### Filters

- `associated_file_references`

- `person_descendant_families`

- `person_timeline_events`